@@ -173,6 +173,9 @@ setValidity("Simulation",
                   return("Variance estimators other than R2 are currently only supported for systematic parallel line designs.")
                 }
               }
+              if(object@ds.analysis@er.var == "P2" && inherits(object@design, "Line.Transect.Design")){
+                return("P2 variance estimator is not applicable for line transect designs. Please check the er.var argument used to create your analysis object.")
+              }
 
               return(TRUE)
             }
@@ -495,7 +498,9 @@ setMethod(
     if(nrow(analysis.strata) > 0){
       #get strata names
       sub.strata.names <- strata.names
-      strata.names <- unique(analysis.strata$analysis.id)
+      tmp.names <- dimnames(object@results$individuals$summary)[[1]]
+      # Remove Total if it exists
+      strata.names <- tmp.names[tmp.names %in% analysis.strata$analysis.id]
       #sum areas of sub strata
       areas <- N <- rep(NA, length(strata.names))
       for(strat in seq(along = strata.names)){
@@ -581,12 +586,16 @@ setMethod(
           new.true.exp.s[strat] <- sum(true.expected.s[index]*N.sub)
         }
         true.expected.s <- new.true.exp.s
+        # Add average (if more than one strata)
+        if(length(size.list) > 1 && length(strata.names) > 1){
+          true.expected.s <- c(true.expected.s, sum(true.N.clusters[1:length(true.expected.s)]*true.expected.s)/sum(true.N.clusters[1:length(true.expected.s)]))
+        }
       }else{
         true.expected.s <- true.expected.s[strata.order]
-      }
-      # Add average
-      if(length(size.list) > 1){
-        true.expected.s <- c(true.expected.s, sum(true.N.clusters[1:length(true.expected.s)]*true.expected.s)/sum(true.N.clusters[1:length(true.expected.s)]))
+        # Add average
+        if(length(size.list) > 1){
+          true.expected.s <- c(true.expected.s, sum(true.N.clusters[1:length(true.expected.s)]*true.expected.s)/sum(true.N.clusters[1:length(true.expected.s)]))
+        }
       }
       #calculate expected number of individuals
       true.N.individuals <- true.N.clusters*true.expected.s
@@ -617,12 +626,23 @@ setMethod(
       RMSE.N = apply(cbind(results$individuals$N[, "Estimate", rep.index], true.N.individuals), 1, calc.RMSE, reps = length(rep.index))
       RMSE.D = apply(cbind(results$individuals$D[, "Estimate", rep.index], true.D.individuals), 1, calc.RMSE, reps = length(rep.index))
     }
+    # Extract values to avoid ifelse below
+    if("n.miss.dist" %in% dimnames(results$individuals$summary)[[2]]){
+      n.miss.dists <- results$individuals$summary[,"n.miss.dist","mean"]
+    }else{
+      n.miss.dists <-  NA
+    }
+    if("k" %in% dimnames(results$individuals$summary)[[2]]){
+      mean.k <- results$individuals$summary[,"k","mean"]
+    }else{
+      mean.k <-  NA
+    }
     individual.summary <- data.frame(mean.Cover.Area = results$individuals$summary[,"CoveredArea","mean"],
                                      mean.Effort = results$individuals$summary[,"Effort","mean"],
                                      mean.n = results$individuals$summary[,"n","mean"],
-                                     mean.n.miss.dist = ifelse("n.miss.dist" %in% dimnames(results$individuals$summary)[[2]], results$individuals$summary[,"n.miss.dist","mean"], NA),
+                                     mean.n.miss.dist = n.miss.dists,
                                      no.zero.n = zero.n,
-                                     mean.k = ifelse("k" %in% dimnames(results$individuals$summary)[[2]], results$individuals$summary[,"k","mean"], NA),
+                                     mean.k = mean.k,
                                      mean.ER = results$individuals$summary[,"ER","mean"],
                                      mean.se.ER = results$individuals$summary[,"se.ER","mean"],
                                      sd.mean.ER = results$individuals$summary[,"ER","sd"])
@@ -674,10 +694,16 @@ setMethod(
         RMSE.N = apply(cbind(results$clusters$N[, "Estimate", rep.index], true.N.clusters), 1, calc.RMSE, reps = length(rep.index))
         RMSE.D = apply(cbind(results$clusters$D[, "Estimate", rep.index], true.D.clusters), 1, calc.RMSE, reps = length(rep.index))
       }
+      # Extract values to avoid ifelse below
+      if("n.miss.dist" %in% dimnames(results$clusters$summary)[[2]]){
+        clus.n.miss.dists <- results$clusters$summary[,"n.miss.dist","mean"]
+      }else{
+        clus.n.miss.dists <-  NA
+      }
       cluster.summary <- data.frame(mean.Cover.Area = results$clusters$summary[,"CoveredArea","mean"],
                                     mean.Effort = results$clusters$summary[,"Effort","mean"],
                                     mean.n = results$clusters$summary[,"n","mean"],
-                                    mean.n.miss.dist = ifelse("n.miss.dist" %in% dimnames(results$clusters$summary)[[2]], results$clusters$summary[,"n.miss.dist","mean"], NA),
+                                    mean.n.miss.dist = clus.n.miss.dists,
                                     no.zero.n = zero.n,
                                     mean.k = results$clusters$summary[,"k","mean"],
                                     mean.ER = results$clusters$summary[,"ER","mean"],
